#!/usr/bin/env python
# encoding: utf-8


import sys
import setuptools
from distutils import log
from pep8 import StyleGuide


class Pep8Command(setuptools.Command):
    description = "run pep8 on all your modules"
    user_options = [
        ('pep8-output=', None, "output report into this file"),
    ]

    def initialize_options(self):
        self.pep8_output = None

    def finalize_options(self):
        if self.pep8_output:
            self.pep8_output = open(self.pep8_output, 'w')

    def run(self):
        if self.pep8_output:
            stdout, sys.stdout = sys.stdout, self.pep8_output
            stderr, sys.stdout = sys.stderr, self.pep8_output

        pep8style = StyleGuide(parse_argv=False, config_file=True)
        options = pep8style.options
	options.exclude.extend(['test', 'tests'])
        report = pep8style.check_files(["."])

        if options.statistics:
            report.print_statistics()
        if options.benchmark:
            report.print_benchmark()
        if report.total_errors:
            if options.count:
                log.error("Total Errors: " + str(report.total_errors))

        if self.pep8_output:
            sys.stdout = stdout
            sys.stderr = stderr
            self.pep8_output.close()




#!/usr/bin/env python
# encoding: utf-8


"""pep8 command for setuptools"""


from setuptools import setup, find_packages
import sys, os


VERSION = '0.1.2'
here = os.path.abspath(os.path.dirname(__file__))
README = open(os.path.join(here, 'README.rst')).read()
NEWS = open(os.path.join(here, 'NEWS.txt')).read()


setup(name='setuptools-pep8',
    version=VERSION,
    description=__doc__,
    long_description=README + '\n\n' + NEWS,
    classifiers=[
        "Topic :: Documentation",
        "Framework :: Setuptools Plugin",
        "Development Status :: 4 - Beta",
        "Programming Language :: Python",
        "Intended Audience :: Developers",
        "Operating System :: OS Independent",
        'License :: OSI Approved :: BSD License',
        "Topic :: Software Development :: Documentation",
        "Topic :: Software Development :: Libraries :: Python Modules",
    ],
    keywords='pep8 setuptools command',
    author='Craig J Perry',
    author_email='craigp84@gmail.com',
    url='https://github.com/CraigJPerry/setuptools-pep8',
    license='BSD',
    packages=find_packages('src'),
    package_dir = {'': 'src'},
    include_package_data=True,
    zip_safe=False,
    install_requires=['pep8'],
    entry_points={
        "distutils.commands": [
            "pep8 = setuptools_pep8.setuptools_command:Pep8Command",
        ]
    }
)

